# Ulm_Weatherballoon

This repository is a library implemented for the Arduino Framework.
It is used for the implementation of dataloggers for use in high-altitude balloons.

Falko Schmidt, 2023

# Supported electrical components

### Sensors

The list below shows all sensors, that are supported by this library.
Please note, that this library is only a lightweight addition to the Arduino framework
to hide some nast details, that might be confusing for students, meaning that many implementations
are defined in other libraries which this depends on.

<table>
    <thead>
        <tr>
            <th>Name of sensor</th>
            <th>Type</th>
            <th>Link (Mouser)</th>
            <th>Link (DigiKey)</th>
            <th>Link (JLCPCB)</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>DS18B20</td>
            <td>Temperature sensor</td>
            <td><a href="https://www.mouser.de/ProductDetail/Analog-Devices-Maxim-Integrated/DS18B20%2b?qs=7H2Jq%252ByxpJKegCKabDbglA%3D%3D">Part at Mouser</a></td>
            <td><a href="https://www.digikey.de/de/products/detail/umw/DS18B20/16705963">Part at DigiKey</a></td>
            <td><a href="https://jlcpcb.com/partdetail/348632-DS18B20/C376006">Part at JLCPCB</a></td>
        </tr>
        <tr>
            <td>LSM6DS3</td>
            <td>Inertial measurement unit (IMU)</td>
            <td><a href="https://www.mouser.de/ProductDetail/STMicroelectronics/LSM6DS3TR-C?qs=u4fy%2FsgLU9NHwPlhP3LTBw%3D%3D">Part at Mouser</a></td>
            <td><a href="https://www.digikey.de/de/products/detail/stmicroelectronics/LSM6DS3HTR/5872322">Part at DigiKey</a></td>
            <td><a href="https://jlcpcb.com/partdetail/Stmicroelectronics-LSM6DS3TR/C95230">Part at JLCPCB</a></td>
        </tr>
        <tr>
            <td>MS5607</td>
            <td>Altimeter</td>
            <td><a href="https://www.mouser.de/ProductDetail/Measurement-Specialties/MS560702BA03-50?qs=urSpXqmdEVImCZG1H%252BT8ng%3D%3D">Part at Mouser</a></td>
            <td><a href="https://www.digikey.de/de/products/detail/te-connectivity-measurement-specialties/MS560702BA03-50/4700931">Part at DigiKey</a></td>
            <td><a href="https://jlcpcb.com/partdetail/TeConnectivity-MS560702BA0350/C97627">Part at JLCPCB</a></td>
        </tr>
    </tbody>
</table>

### Actors

A datalogger not just consists of sensors. There also has to be some
output to the user in case of an error. For this, several actors can be used:

<table>
    <thead>
        <tr>
            <th>Name</th>
            <th>Description</th>
            <th>Implementation (Header)</th>
            <th>Comments</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>Generic LED</td>
            <td>A simple LED that is connected to a GPIO of a microcontroller.</td>
            <td><a href="src/Ulm_LED.h">Implementation</a></td>
            <td>
                An LED can either be ACTIVE_HIGH, meaning that it is ON, if pin is HIGH. Otherwise, it is ACTIVE_LOW, 
                meaning it is ON, if pin is LOW. Please make sure to use the correct setting, otherwise your LED will 
                react inverted!
            </td>
        </tr>
        <tr>
            <td>Built-In LED</td>
            <td>The on-board LED of an Arduino.</td>
            <td><a href="src/Ulm_LED_BuiltIn.h">Implementation</a></td>
            <td>
                Use this to control the built-in LED of an Arduino. You do not need to pass any pin, this will
                be done automatically.
            </td>
        </tr>
        <tr>
            <td>RGB LED (a.k.a. NeoPixel)</td>
            <td>A single NeoPixel RGB LED connected to any GPIO of the microcontroller.</td>
            <td><a href="src/Ulm_RGB_LED.h">Implementation</a></td>
            <td>
                This implementation only works for a SINGLE NeoPixel. If you want to controll a chain of them, then
                please refer to the Adafruit NeoPixel library instead!
            </td>
        </tr>
        <tr>
            <td>OLED-Display</td>
            <td>A small OLED-display that has the dimensions of 128 x 64 pixels.</td>
            <td><a href="src/Ulm_OLED_Display.h">Implementation</a></td>
            <td>
                This only works for the dimension of 128 x 64 pixels and the i2c address 0x3C. If your display does
                not apply to these characteristics, then the implementation can not be used!
            </td>
        </tr>
    </tbody>
</table>

### Storage modules
Of course, sampling sensors it not enough. You need to store
your read values somewhere. These implementations can be used
to store data:
<table>
    <thead>
        <tr>
            <th>Name</th>
            <th>Description</th>
            <th>Implementation (Header)</th>
            <th>Comments</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>SD-Storage</td>
            <td>SD-Card storage with configurable auto-detect pin and optional data redundancy implementation</td>
            <td><a href="src/Ulm_SDStorage.h">Implementation</a></td>
            <td>
                --- INFORMATION WILL FOLLOW SOON ---
                Please note, that this implementation is complex - information will be added after a ton of testing!
            </td>
        </tr>
    </tbody>
</table>


# Supported data-loggers

Below you can find a list of supported data-loggers by this library.
Several designs will be added in near future!

### SGUduino 2024 [Falko Schmidt]

![SGUduino 2024 (Top)](assets/SGUduino_2024_Top.png)

The SGUduino 2024 Datalogger was created for the Seminar NWT course, that took place 2023-2024
at Ulm University. This PCB was created to show students a way how to structure sensors in a
neat way on a PCB that can be used with an Arduino UNO.
These electrical components are used:
<ul>
<li>RGB LED of type 'WS2812'</li>
<li>RESET button</li>
<li>DS18B20 temperature sensor</li>
<li>LSM6DS3 IMU</li>
<li>microSD card with logic-level-converter</li>
<li>MS5607 altimeter</li>
<li>stemmaQT connector for further external sensors.</li>
</ul>

With the sensor set mentioned above, several different charactical values of the atmosphere
can be measured during the flight in a weather balloon:
<ul>
<li>Uptime [ms]</li>
<li>Surrounding temperature [°C]</li>
<li>Gyroscope X, Y and Z [deg/s]</li>
<li>Acceleration X, Y and Z [g]</li>
<li>Air pressure [mBar]</li>
<li>Altitude above sea level [m]</li>
</ul>

If you have this PCB and want to start programming and testing, then check out
[the ready-to-run program](examples/Ulm_Datalogger_SGUduino2024).
